# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class OCRRequestRequestMode(StrEnum):
    """
    OCR mode affecting quality and speed
    * `tiny` - Tiny - fastest, basic text extraction
    * `small` - Small - fast, good for simple text
    * `base` - Base - balanced speed and accuracy
    * `maximum` - Maximum - best accuracy, slower
    """

    TINY = "tiny"
    SMALL = "small"
    BASE = "base"
    MAXIMUM = "maximum"



class VisionAnalyzeRequestRequestModelQuality(StrEnum):
    """
    Model quality tier (fast, balanced, best)
    * `fast` - Fast - lower quality, cheaper
    * `balanced` - Balanced - good quality, reasonable cost
    * `best` - Best - highest quality, most expensive
    """

    FAST = "fast"
    BALANCED = "balanced"
    BEST = "best"



