# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class CDNJobStatusStatus(StrEnum):
    """
    Job status
    * `queued` - queued
    * `started` - started
    * `finished` - finished
    * `failed` - failed
    * `deferred` - deferred
    """

    QUEUED = "queued"
    STARTED = "started"
    FINISHED = "finished"
    FAILED = "failed"
    DEFERRED = "deferred"



