# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class ImageGenerateRequestRequestQuality(StrEnum):
    """
    Image quality
    * `standard` - Standard
    * `hd` - HD
    """

    STANDARD = "standard"
    HD = "hd"



class ImageGenerateRequestRequestStyle(StrEnum):
    """
    Image style
    * `natural` - Natural
    * `vivid` - Vivid
    """

    NATURAL = "natural"
    VIVID = "vivid"



class ImageGenerateResponseStatus(StrEnum):
    """
    * `pending` - Pending
    * `queued` - Queued
    * `processing` - Processing
    * `completed` - Completed
    * `failed` - Failed
    * `cancelled` - Cancelled
    """

    PENDING = "pending"
    QUEUED = "queued"
    PROCESSING = "processing"
    COMPLETED = "completed"
    FAILED = "failed"
    CANCELLED = "cancelled"



