# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class SearchAsyncRequestRequestMode(StrEnum):
    """
    * `search` - Search
    * `research` - Research
    * `analyze` - Analyze
    * `comprehensive` - Comprehensive
    * `investigate` - Investigate
    """

    SEARCH = "search"
    RESEARCH = "research"
    ANALYZE = "analyze"
    COMPREHENSIVE = "comprehensive"
    INVESTIGATE = "investigate"



