# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class PaymentDetailStatus(StrEnum):
    """
    * `pending` - Pending
    * `confirming` - Confirming
    * `confirmed` - Confirmed
    * `completed` - Completed
    * `partially_paid` - Partially Paid
    * `failed` - Failed
    * `expired` - Expired
    * `cancelled` - Cancelled
    """

    PENDING = "pending"
    CONFIRMING = "confirming"
    CONFIRMED = "confirmed"
    COMPLETED = "completed"
    PARTIALLY_PAID = "partially_paid"
    FAILED = "failed"
    EXPIRED = "expired"
    CANCELLED = "cancelled"



class PaymentProviderProviderType(StrEnum):
    """
    * `nowpayments` - NowPayments
    * `stripe` - Stripe
    * `coinbase` - Coinbase Commerce
    """

    NOWPAYMENTS = "nowpayments"
    STRIPE = "stripe"
    COINBASE = "coinbase"



class ProviderCredentialCreateRequestProviderType(StrEnum):
    """
    * `nowpayments` - nowpayments
    * `stripe` - stripe
    * `coinbase` - coinbase
    """

    NOWPAYMENTS = "nowpayments"
    STRIPE = "stripe"
    COINBASE = "coinbase"



class TransactionTransactionType(StrEnum):
    """
    * `deposit` - Deposit
    * `withdrawal` - Withdrawal
    * `payment` - Payment
    * `refund` - Refund
    * `fee` - Fee
    * `adjustment` - Adjustment
    """

    DEPOSIT = "deposit"
    WITHDRAWAL = "withdrawal"
    PAYMENT = "payment"
    REFUND = "refund"
    FEE = "fee"
    ADJUSTMENT = "adjustment"



class WithdrawalDetailStatus(StrEnum):
    """
    * `pending` - Pending
    * `approved` - Approved
    * `processing` - Processing
    * `completed` - Completed
    * `rejected` - Rejected
    * `cancelled` - Cancelled
    """

    PENDING = "pending"
    APPROVED = "approved"
    PROCESSING = "processing"
    COMPLETED = "completed"
    REJECTED = "rejected"
    CANCELLED = "cancelled"



